Module player

Module player 

contains system for player-controlled interactions

Functions

player_system
This system defines all of the interactions that are possible for the player-controlled Warrior. The play_turn method is called on Player, passing a &mut warrior whose actions must be specified.