Player

Trait Player 

pub trait Player: Send + Sync {
    // Required method
    fn play_turn(&mut self, warrior: &Warrior);
}
An implementation of this trait is provided when rust-warrior is executed to generate your initial game files. Your struct will be named according to the name you chose.

Required Methods

fn play_turn(&mut self, warrior: &Warrior)

This method is called by the game engine repeatedly, once per turn. See Warrior to see which actions you can instruct the Warrior to take.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors