contains some helper functions for prompting input from the player
Functions
- ask
- Helper function for prompting the player with a yes/no question
- request
- Helper function for prompting the player for a response
- select_
level
contains some helper functions for prompting input from the player