Module warrior

Module warrior 

contains the interface exposed to the player for controlling the Warrior

Structs

Warrior
An interface the player can interact with to control the Warrior in the game. An instance is passed to Player via the play_turn method. The player must pick one Action to perform each turn. Not all abilities are an Action. Warrior abilities are unlocked as the player progresses through the levels.