contains the trait exposed to the player for controlling the Warrior
Traits
- Player
- An implementation of this trait is provided when
rust-warrioris executed to generate your initial game files. Your struct will be named according to the name you chose.