contains the interface exposed to the player for controlling the Warrior
Structs
- Warrior
- An interface the player can interact with to control the Warrior in the
game. An instance is passed to
Playervia theplay_turnmethod. The player must pick oneActionto perform each turn. Not all abilities are anAction. Warrior abilities are unlocked as the player progresses through the levels.